//
//  YHPhoneLiginWithVideoBkgViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/5/19.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import IQKeyboardManagerSwift
import AVFoundation

class YHPhoneLiginWithVideoBkgViewController: YHBaseViewController {
    
    var bgImageView: UIImageView!
    var closeButton: UIButton!
    var logImageView: UIImageView!
    var loginTitleLabel: UILabel!
    var loginSubTitleLabel: UILabel!
    var phoneMessageView: YHPhoneMessageView!
    var getCodeButton: UIButton!
    var privacyView: YHLoginPrivacyView!
    var viewModel: YHLoginViewModel?
    
    
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setView()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        YHAnalytics.timeStrat("loginTime")
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        YHAnalytics.timeEnd("loginTime")
    }
    
    override func viewDidDisappear(_ animated: Bool) {
        super.viewDidDisappear(animated)
    }
    
    
    
    //视频
    private var player: AVPlayer?
    private var playerLayer: AVPlayerLayer?
    
    lazy var frontHoldView: UIView = {
        let view = UIView()
        view.backgroundColor = UIColor(hex: 0x121A26, alpha: 0.32)
        return view
    }()
    
    
    lazy var contentHoldView: UIView = {
        let view = UIView()
        view.backgroundColor = .clear
//        view.backgroundColor = .red //for test hjl
        return view
    }()
}

extension YHPhoneLiginWithVideoBkgViewController {
    
    func setView() {
        view.backgroundColor = .white
        
        gk_navBackgroundColor = .clear
        gk_navShadowColor = .clear
        gk_navigationBar.isHidden = true
        
        viewModel = YHLoginViewModel()
        
        setupBackgroundVideo()
        
        setupFrontUI()
    }
    
    func setupFrontUI() {
        view.addSubview(frontHoldView)
        frontHoldView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        
//        bgImageView = {
//            let imageView = UIImageView()
//            imageView.image = UIImage(named: "login_phone_bg_image")
//            imageView.isUserInteractionEnabled = true
//            return imageView
//        }()
//        frontHoldView.addSubview(bgImageView)
//        bgImageView.snp.makeConstraints { make in
//            make.left.right.top.equalTo(view)
//            make.height.equalTo(300)
//        }
        
        closeButton = {
            let button = UIButton(type: .custom)
            button.setImage(UIImage(named: "login_close"), for: .normal)
            button.addTarget(self, action: #selector(close), for: .touchUpInside)
            return button
        }()
        frontHoldView.addSubview(closeButton)
        closeButton.snp.makeConstraints { make in
            make.left.equalTo(13)
            make.top.equalTo(51)
            make.width.height.equalTo(30)
        }
        
        logImageView = {
            let imageView = UIImageView()
            imageView.image = UIImage(named: "login_icon")
            imageView.layer.masksToBounds = true
            imageView.layer.cornerRadius = kCornerRadius8
            return imageView
        }()
        frontHoldView.addSubview(logImageView)
        logImageView.snp.makeConstraints { make in
            make.left.equalTo(24)
            make.top.equalTo(closeButton.snp.bottom).offset(32)
            make.width.equalTo(82)
            make.height.equalTo(30)
            
        }
        loginTitleLabel = {
            let label = UILabel()
            label.text = "欢迎来到银河港生活"
            label.font = UIFont.PFSC_B(ofSize: 30)
            label.textColor = UIColor.white
            return label
        }()
        frontHoldView.addSubview(loginTitleLabel)
        loginTitleLabel.snp.makeConstraints { make in
            make.left.equalTo(logImageView.snp.left)
            make.right.equalTo(-24)
            make.top.equalTo(logImageView.snp.bottom).offset(12)
            make.height.equalTo(42)
        }
        
        loginSubTitleLabel = {
            let label = UILabel()
            label.text = "手机号首次登录自动注册"
            label.font = UIFont.PFSC_R(ofSize: 15)
            label.textColor =  UIColor(hex: 0xffffff, alpha: 0.8)
            return label
        }()
        frontHoldView.addSubview(loginSubTitleLabel)
        loginSubTitleLabel.snp.makeConstraints { make in
            make.left.equalTo(logImageView.snp.left)
            make.right.equalTo(-24)
            make.top.equalTo(loginTitleLabel.snp.bottom).offset(4)
            make.height.equalTo(20)
        }
        
        
        
        frontHoldView.addSubview(contentHoldView)
        contentHoldView.snp.makeConstraints { make in
            make.bottom.equalToSuperview().offset(-40)
            make.left.right.equalToSuperview()
        }
        
        phoneMessageView = {
            let view = YHPhoneMessageView()
            view.backgroundColor =  .clear//UIColor.contentBkgColor
//            view.layer.cornerRadius = kCornerRadius6
//            view.layer.borderWidth = 1
//            view.layer.borderColor = UIColor(hex:0xebeef4).cgColor
            view.phoneBlock = {[weak self] count in
                guard let self = self else { return }
                if count == 0 {
                    self.getCodeButton.backgroundColor =  UIColor.white.withAlphaComponent(0.4)
                    self.getCodeButton.isEnabled = false
                } else {
                    self.getCodeButton.backgroundColor =  UIColor.white
                    self.getCodeButton.isEnabled = true
                }
            }
            return view
        }()
        contentHoldView.addSubview(phoneMessageView)
        phoneMessageView.snp.makeConstraints { make in
            make.left.equalTo(20)
            make.right.equalTo(-20)
            make.top.equalTo(0)
            make.height.equalTo(44)
        }
        
        getCodeButton = {
            let button = UIButton(type: .custom)
            button.backgroundColor =  UIColor.white.withAlphaComponent(0.4)
            button.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
            button.contentHorizontalAlignment = .center
            button.setTitle("获取验证码", for: .normal)
            button.setTitleColor( UIColor(hex:0x000000), for: .normal)
            button.layer.cornerRadius = 24
            button.addTarget(self, action: #selector(getCode), for: .touchUpInside)
            button.isEnabled = false
            return button
        }()
        contentHoldView.addSubview(getCodeButton)
        getCodeButton.snp.makeConstraints { make in
            make.left.equalTo(20)
            make.right.equalTo(-20)
            make.top.equalTo(phoneMessageView.snp.bottom).offset(32)
            make.height.equalTo(48)
        }
        
        privacyView = {
            let view = YHLoginPrivacyView()
            return view
        }()
        contentHoldView.addSubview(privacyView)
        privacyView.snp.makeConstraints { make in
            make.top.equalTo(getCodeButton.snp.bottom).offset(24)
            make.left.equalTo(20)
            make.height.equalTo(20)
            make.width.equalTo(260)
            make.bottom.equalToSuperview()
        }
    }
    
    @objc func getCode() {
        
        IQKeyboardManager.shared.resignFirstResponder()
        
        let phoneNumer = phoneMessageView.phoneTextField.text ?? ""
        guard phoneNumer.isMobile() == true else {
            YHHUD.flash(message: "请输入正确的手机号")
            return
        }
        if privacyView.isAgree {
            YHHUD.show(.progress(message: ""))
            viewModel?.getLoginCode(phoneNumer, callBackBlock: {[weak self] success,error in
                YHHUD.hide()
                
                guard let self = self else { return }
                
                if success == true {
                    let vc = YHCodeSueecssViewController()
                    vc.phoneNumber = self.phoneMessageView.phoneTextField.text
                    self.navigationController?.pushViewController(vc)
                } else {
                    var msg = error?.errorMsg ?? ""
                    if msg.isEmpty {
                        msg = String(error?.errorCode ?? 404)
                    }
                    YHHUD.flash(message: msg)
                }
            })
        } else {
            let view = YHPrivacyAlertView(frame: view.bounds)
            view.urlBlock = { [weak self] (type,url) in
                guard let self = self else { return }
                let vc = YHWebViewViewController()
                vc.url = url
                if type == 0 {
                    vc.navTitle = "银河港生活隐私政策"
                } else if type == 1 {
                    vc.navTitle = "银河港生活用户条款"
                }
                
                self.navigationController?.pushViewController(vc)
            }
            view.agreeBlock = { [weak self] in
                guard let self = self else { return }
                self.privacyView.isAgree = true
                self.getCode()
            }
            self.view.addSubview(view)
        }
    }
    
    @objc func close() {
        YHLoginManager.shared.loginSuccessActionBlock = nil
        self.dismiss(animated: true)
    }
}


extension YHPhoneLiginWithVideoBkgViewController {
    private func setupBackgroundVideo() {
        guard let videoURL = Bundle.main.url(forResource: "loginBkg", withExtension: "mov") else { return }
        player = AVPlayer(url: videoURL)
        player?.actionAtItemEnd = .none
        playerLayer = AVPlayerLayer(player: player)
        playerLayer?.frame = view.bounds
        playerLayer?.videoGravity = .resizeAspectFill
        view.layer.insertSublayer(playerLayer!, at: 0)
        player?.play()
        
        
        NotificationCenter.default.addObserver(self, selector: #selector(playerItemDidPlayToEndTimeNotification), name: AVPlayerItem.didPlayToEndTimeNotification, object: nil)
    }
    
    @objc func playerItemDidPlayToEndTimeNotification() {
        player?.seek(to: .zero)
    }
}
